@@ -310,6 +310,8 @@ void Account::validateToken(bool newAccount)
                 config()->setEnablePushNotifications(true);
                 config()->save();
             }
+#else
+            Q_UNUSED(newAccount)
 #endif
 
 #ifdef HAVE_KUNIFIEDPUSH
@@ -531,4 +533,4 @@ QUrlQuery Account::buildNotificationFormData()
     return formdata;
 }
 
-#include "moc_account.cpp"
\ No newline at end of file
+#include "moc_account.cpp"
