@@ -4,7 +4,7 @@
 #pragma once
 
 #include "abstractaccount.h"
-#include "timeline/post.h"
+#include "post.h"
 
 /// Account-specific preferences which are stored server-side
 class Preferences : public QObject
