@@ -1,13 +1,11 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "account/accountmanager.h"
 #include "admin/federationtoolmodel.h"
 #include "helperreply.h"
 #include "mockaccount.h"
 
-#include <QAbstractItemModelTester>
-#include <QSignalSpy>
 #include <QtTest/QtTest>
 
 class FederationToolTest : public QObject
