@@ -2,13 +2,10 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "searchmodel.h"
-#include "account/abstractaccount.h"
-#include "account/account.h"
-#include "timeline/accountmodel.h"
+
+#include "account.h"
+
 #include <KLocalizedString>
-#include <QNetworkReply>
-#include <QUrlQuery>
-#include <algorithm>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -169,3 +166,5 @@ QString SearchHashtag::getName() const
 {
     return m_name;
 }
+
+#include "moc_searchmodel.cpp"
